%% Author Information
% Calculate the Frequency of the strongest signal
%
% George Smart, MEng.
% Department of Electronic & Electrical Engineering
% University College London
%
% http://www.george-smart.co.uk/
%

%% Preliminaries
logFile = fopen('FunCube_GB3VHF.log', 'a');
recorder = audiorecorder(96000, 16, 2);

while (1==1)
    %% Record Sound
    recordblocking(recorder, 1);
    raw_samples = getaudiodata(recorder);
    complex_samples = raw_samples(:,1) + 1i*raw_samples(:,2);
    
    %% FFT Input Data
    raw_fft = fft(complex_samples);
    shifted_fft = fftshift(raw_fft);
    abs_fft = abs(shifted_fft);
    
    %% Calculate Graph Scaling
    fVector=[((-recorder.SampleRate+0)/2):(recorder.SampleRate/(recorder.TotalSamples-1)):((recorder.SampleRate-0)/2)];
    
    %% Filter
    BandStart = 1e4; % Hz
    BandStop = 2e4; % Hz
    DigitalStart = ((BandStart/max(fVector-1))/2)+0.5; % normalised
    DigitalStop = ((BandStop/max(fVector-1))/2)+0.5;
    
    PassBand = fir1 (1000, [DigitalStart DigitalStop]);
    PassBand = freqz(PassBand,1,recorder.TotalSamples);
    PassBand = abs(PassBand);
    
    FilteredData = abs_fft(:,1) .* PassBand;
    
    %% Plot Graph
    plot(fVector, FilteredData);
	axis([0 3e4 0 100]);
    title('Filtered FFT');
    xlabel('Frequency/Hz');
    ylabel('Relative Scaled Input Level');
    
    %% Record Data
    Threshold = 100;
    [maxFDat, maxEle] = max(FilteredData);
    if (maxFDat > Threshold)
        DATE_NOW = datestr(now, 'dd/mm/yy');
        TIME_NOW = datestr(now, 'HH:MM:SS');
        PS_NOW = datestr(now, '20yymmddHHMMSS');
        maxFreq = fVector(maxEle);
        fprintf('| %s | %s | %d | %d | %d |\n', DATE_NOW, TIME_NOW, maxFDat, maxEle, maxFreq);
        fprintf(logFile, '%s,%s,%d,%d,%d\n', DATE_NOW, TIME_NOW, maxFDat, maxEle, maxFreq);
        print('-dpng', PS_NOW);
    end
end
